/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */


package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;

/**
 * TIC3 Info XML Element: TicId (TID), Globaler	eindeutiger Identifikator der Information.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TIC3ID.java 63650 2016-09-22 17:11:32Z gieseler $  
 */

public class TIC3ID extends AbstractTIC3InfoElement {

	/**
	 * TIC3 Info XML Element: TicId (TID), Globaler	eindeutiger Identifikator der Information.
	 */
	private static final String XML_ELEMENT_ID = "TIC3TicId";

	/**
	 * Name der Organisation, welche die Meldung publiziert hat. TIC Info XML
	 * Element: IDOrganisation, Name der publizierenden Organisation.
	 */
	private static final String XML_ELEMENT_IDORGANISATION = "ORG";
	/**
	 * Laufende Nummer der Meldung. TIC Info XML Element: IDNumber, Fortlaufende
	 * Nummer der Meldung innerhalb der publizierenden Organisation
	 */
	private static final String XML_ELEMENT_IDNUMBER = "NUM";

	/**
	 * Name der Organisation, welche die Meldung publiziert hat.
	 */
	private final TIC3Text idOrganisation = new TIC3Text(TIC3ID.XML_ELEMENT_IDORGANISATION, "IDOrganisation");
	/**
	 * Laufende Nummer der Meldung.
	 */
	private final TIC3Text idNumber = new TIC3Text(TIC3ID.XML_ELEMENT_IDNUMBER, "IDNummer");

	/**
	 * Konstruktor.
	 */
	public TIC3ID() {
		super(TIC3ID.XML_ELEMENT_ID, "ID");
		addKindElement(idOrganisation);
		addKindElement(idNumber);
	}

	/**
	 * Gibt die IDNumber der Meldung zur&uuml;ck.
	 *
	 * @return IDNumber der Meldung
	 */
	protected String getIDNumber() {
		return idNumber.getText();
	}

	/**
	 * Gibt die IDOrganisation der Meldung zur&uuml;ck.
	 *
	 * @return IDOrganisation der Meldung
	 */
	protected String getIDOrganisation() {
		return idOrganisation.getText();
	}

	/**
	 * Setzt die IDNumber der Meldung.
	 *
	 * @param nummer
	 *            IDNumber
	 */
	protected void setIDNumber(final String nummer) {
		idNumber.setText(nummer);
	}

	/**
	 * Setzt die IDOrganisation der Meldung.
	 *
	 * @param organisation
	 *            IDOrganisation der Meldung
	 */
	protected void setIDOrganisation(final String organisation) {
		idOrganisation.setText(organisation);
	}

}
