/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import org.w3c.dom.Node;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.kex.lmstic3.vew.LMSParameter;
import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;

/**
 * TIC3-Netzgebiet.
 * 
 * <p>
 * TIC Info XML Element: NetworkArea (NAR), Information about an area such as
 * the reference and description.
 * </p>
 * <p>
 * Entspricht TIC3 Info Typ 'NetworkAreaType'.
 * </p>
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TIC3NetzGebiet.java 63650 2016-09-22 17:11:32Z gieseler $
 */
public class TIC3NetzGebiet extends AbstractTIC3InfoElement {

	/**
	 * TIC Info XML Element: NetworkArea (NAR), Information about an area such
	 * as the reference and description.
	 */
	public static final String XML_ELEMENT_NETWORKAREA = "NetworkArea";

	/**
	 * DAV-Attribut.
	 */
	private static final String DAV_ATTR_NETWORKAREA = "TIC3Netzgebiet";

	/**
	 * TIC3 Gebietskennung. TIC Info XML Element: NetworkAreaIdentifier (NAI), A
	 * reference to "Area".
	 */
	private TIC3Text gebietsKennung = new TIC3Text("NetworkAreaIdentifier", "Gebietskennung", "value");

	private TIC3NetzGebietBeschreibung netzGebietBeschreibung = new TIC3NetzGebietBeschreibung();

	/**
	 * Erzeugt ein neues Objekt.
	 */
	public TIC3NetzGebiet() {
		super(XML_ELEMENT_NETWORKAREA, DAV_ATTR_NETWORKAREA);

		/**
		 * Beschreibung des Gebietes. Wert des 'description'-Attributes TIC Info
		 * XML Element NetworkArea.
		 */
		addAttribut("description", "Beschreibung");

		addKindElement(gebietsKennung);

		addKindElement(netzGebietBeschreibung);
	}

	@Override
	public void einlesenXML(final Node node) throws TIC3Exception {
		super.einlesenXML(node);
		// final NodeList nl = node.getChildNodes();
		//
		// for (int i = 0; i < nl.getLength(); i++) {
		// final Node n = nl.item(i);
		// if (n.getNodeName().equals(TIC3TMCLocation.XML_ELEMENT_TMCLOC)) {
		// final TIC3TMCLocation loc = new TIC3TMCLocation();
		// loc.einlesenXML(n);
		// tic3TMCLocationen.add(loc);
		// }
		// }
	}

	@Override
	public void publizieren(final Data davdata, final LMSParameter parameter) throws TIC3Exception {
		if (hasData()) {
			super.publizieren(davdata, parameter);
		}
	}

	private boolean hasData() {
		return gebietsKennung.getText().length() > 0;
	}
}
