/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;

/**
 * Repr&auml;sentiert ein textuelles TIC3-Element.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TIC3Text.java 63650 2016-09-22 17:11:32Z gieseler $
 */

public class TIC3Text extends AbstractTIC3InfoElement {

	/**
	 * Text.
	 */
	private String text = "";

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 */
	public TIC3Text(final String xmlName, final String davName) {
		super(xmlName, davName);
	}

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 * @param wertAttribut
	 *			Name des (XML-)Attributes, dass zur Bestiimung des Wertes benutzt werden soll 				
	 */
	public TIC3Text(final String xmlName, final String davName, final String wertAttribut) {
		super(xmlName, davName, wertAttribut);
	}

	@Override
	public void getDavDaten(final Data davdata) throws TIC3Exception {
		this.text = davdata.getTextValue(getDavAttributName()).getText();
	}

	/**
	 * Gibt den Text zur&uuml;ck.
	 *
	 * @return Text
	 */
	public String getText() {
		return text;
	}

	@Override
	public void getXmlDaten(final Node node) {
		if (useAttributValue()) {
			text = getWertAttribut().getXmlValue();
		} else {
			text = node.getTextContent();
		}
	}

	@Override
	public void setDavDaten(final Data davdata) throws TIC3Exception {
		davdata.getTextValue(getDavAttributName()).setText(text);
	}

	/**
	 * Setzt den Text.
	 *
	 * @param text
	 *            neuer Text
	 */
	public void setText(final String text) {
		this.text = text;
	}

	@Override
	public void setXmlDaten(final Element element) {
		element.setTextContent(text);
	}

	@Override
	public String toString() {
		return "XML-Element '" + getXmlElementName() + "': name='" + getNameAttribut().getXmlValue() + "', Wert='"
				+ text + "'" + "; DAV-Attribut '" + getDavAttributName() + "'";
	}
}
