/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tmc;

/**
 * TMC-Ereignis.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id: TMCEvent.java 63650 2016-09-22 17:11:32Z gieseler $
 */

public class TMCEvent {

	/**
	 * Enumerator TMC-Ereignistyp.
	 */
	public enum TMCEventType {

		/** Unbekannt. */
		Unbekannt("Unbekannt", 0),

		/** Ereigniscode. */
		Ereigniscode("Ereigniscode", 1),

		/** Empfehlungscode. */
		Empfehlungscode("Empfehlungscode", 2);

		/**
		 * textueller Wert.
		 */
		private final String value;

		/**
		 * numerischer Wert.
		 */
		private int id;

		/**
		 * Privater Konstruktor.
		 *
		 * @param value
		 *            textueller Wert
		 * @param id
		 *            numerischer Wert
		 */
		TMCEventType(final String value, final int id) {
			this.value = value;
			this.id = id;
		}

		/**
		 * Gibt den numerischen Wert zur&uuml;ck.
		 *
		 * @return numerischer Wert des Typs
		 */
		public int getId() {
			return id;
		}

		/**
		 * Gibt den textuellen Wert zur&uuml;ck.
		 *
		 * @return textueller Wert des Typs
		 */
		public String getValue() {
			return value;
		}
	}

	/**
	 * Typ.
	 */
	private TMCEventType typ = TMCEventType.Unbekannt;

	/**
	 * Code.
	 */
	private int code;

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param typ
	 *            Ereignistyp {@link TMCEventType}
	 * @param code
	 *            Codenummer
	 */
	public TMCEvent(final TMCEventType typ, final int code) {
		this.typ = typ;
		this.code = code;
	}

	/**
	 * Gibt den Typ des Ereignisses zur&uuml;ck.
	 * 
	 * @return {@link TMCEventType}
	 */
	public TMCEventType getTyp() {
		return typ;
	}

	/**
	 * Gibt den Ereigniscode zur&uuml;ck.
	 * 
	 * @return Ereigniscode
	 */
	public int getCode() {
		return code;
	}
}
